@@ -43,12 +43,17 @@
         data[] <- lapply(data, function(x) {
             x <- as.character(x)
             x[x == dc.code] <- -1
-            return(asNumeric(x))
+            if (possibleNumeric(x)) {
+                x <- asNumeric(x)
+            }
+            return(x)
         })
         colnames(data) <- colnms
     }
     fuzzy.cc <- logical(ncol(data))
     hastime <- logical(ncol(data))
+    factor <- unlist(lapply(data, is.factor))
+    declared <- unlist(lapply(data, function(x) inherits(x, "declared")))
     pN <- unlist(lapply(data, possibleNumeric))
     for (i in seq(ncol(data))) {
         if (pN[i]) {
@@ -64,5 +69,48 @@
         }
     }
     noflevels <- getLevels(data)
-    return(list(data = data, fuzzy.cc = fuzzy.cc, hastime = hastime, dc.code = dc.code, noflevels = as.numeric(noflevels)))
+    attributes(noflevels) <- NULL
+    factor <- factor & !hastime
+    categories <- list()
+    columns <- colnames(data)
+    if (any(factor | declared)) {
+        for (i in which(factor | declared)) {
+            if (factor[i]) {
+                values <- seq(noflevels[i]) - 1
+                names(values) <- levels(data[, i])
+                data[, i] <- as.numeric(data[, i]) - 1
+                categories[[columns[i]]] <- values
+            }
+            else {
+                values <- seq(noflevels[i]) - 1
+                x <- data[, i]
+                labels <- attr(x, "labels")
+                if (is.null(labels)) {
+                    stopError("Declared columns should have labels for all values.")
+                }
+                else {
+                    if (length(labels) != noflevels[i]) {
+                        stopError("All values should have declared labels.")
+                    }
+                }
+                attributes(x) <- NULL
+                data[, i] <- recode(x, paste(sort(labels), values, sep = "=", collapse = ";"))
+                names(values) <- names(labels)
+                categories[[columns[i]]] <- values
+                attr(categories, "labels") <- labels
+            }
+        }
+    }
+    return(
+        list(
+            data = data,
+            fuzzy.cc = fuzzy.cc,
+            hastime = hastime,
+            factor = factor,
+            declared = declared,
+            categories = categories,
+            dc.code = dc.code,
+            noflevels = noflevels
+        )
+    )
 }
